@@ -25,9 +25,7 @@ sub dequeue {
 }
 
 sub enqueue {
-  my ($self, $task) = (shift, shift);
-  my $args    = shift // [];
-  my $options = shift // {};
+  my ($self, $task, $args, $options) = (shift, shift, shift || [], shift || {});
 
   my $db = $self->pg->db;
   return $db->query(
@@ -133,8 +131,7 @@ sub repair {
 sub reset { shift->pg->db->query('truncate minion_jobs, minion_workers') }
 
 sub retry_job {
-  my ($self, $id, $retries) = (shift, shift, shift);
-  my $options = shift // {};
+  my ($self, $id, $retries, $options) = (shift, shift, shift, shift || {});
 
   return !!$self->pg->db->query(
     "update minion_jobs
@@ -142,7 +139,7 @@ sub retry_job {
        retried = now(), retries = retries + 1, state = 'inactive',
        delayed = (now() + (interval '1 second' * ?))
      where id = ? and retries = ?
-       and state in ('failed', 'finished', 'inactive')
+       and state in ('inactive', 'failed', 'finished')
      returning 1", @$options{qw(priority queue)}, $options->{delay} // 0, $id,
     $retries
   )->rows;
@@ -720,14 +717,21 @@ alter table minion_workers add column
   notified timestamp with time zone not null default now();
 alter table minion_workers alter column started set default now();
 
--- 3 up
-create index on minion_jobs (state);
-
 -- 4 up
 alter table minion_jobs add column queue text not null default 'default';
 
 -- 5 up
 alter table minion_jobs add column attempts int not null default 1;
 
--- 6 up
-drop index minion_jobs_state_idx;
+-- 7 up
+create type minion_state as enum ('inactive', 'active', 'failed', 'finished');
+alter table minion_jobs alter column state set default 'inactive'::minion_state;
+alter table minion_jobs
+  alter column state type minion_state using state::minion_state;
+alter table minion_jobs alter column args type jsonb using args::jsonb;
+alter table minion_jobs alter column result type jsonb using result::jsonb;
+
+-- 7 down
+alter table minion_jobs alter column state type text using state;
+alter table minion_jobs alter column state set default 'inactive';
+drop type if exists minion_state;
