@@ -12,12 +12,11 @@ sub dequeue {
   my $minion = $self->minion;
   return undef unless my $job = $minion->backend->dequeue($id, $wait, $options);
   $job = Minion::Job->new(
-    args     => $job->{args},
-    attempts => $job->{attempts},
-    id       => $job->{id},
-    minion   => $minion,
-    retries  => $job->{retries},
-    task     => $job->{task}
+    args    => $job->{args},
+    id      => $job->{id},
+    minion  => $minion,
+    retries => $job->{retries},
+    task    => $job->{task}
   );
   $self->emit(dequeue => $job);
   return $job;
@@ -99,8 +98,9 @@ implements the following new ones.
   my $job = $worker->dequeue(0.5);
   my $job = $worker->dequeue(0.5 => {queues => ['important']});
 
-Wait for job, dequeue L<Minion::Job> object and transition from C<inactive> to
-C<active> state or return C<undef> if queues were empty.
+Wait a given amount of time in seconds for a job, dequeue L<Minion::Job> object
+and transition from C<inactive> to C<active> state, or return C<undef> if queues
+were empty.
 
 These options are currently available:
 
@@ -173,6 +173,6 @@ Unregister worker.
 
 =head1 SEE ALSO
 
-L<Minion>, L<Mojolicious::Guides>, L<http://mojolicio.us>.
+L<Minion>, L<Mojolicious::Guides>, L<http://mojolicious.org>.
 
 =cut
